@@ -19,6 +19,8 @@
  */
 #include "plugin.h"
 #include "windowsystem.h"
+#include "windoweffects.h"
+#include "windowinfo.h"
 
 KWaylandPlugin::KWaylandPlugin(QObject *parent)
     : KWindowSystemPluginInterface(parent)
@@ -29,7 +31,17 @@ KWaylandPlugin::~KWaylandPlugin()
 {
 }
 
+KWindowEffectsPrivate *KWaylandPlugin::createEffects()
+{
+    return new WindowEffects();
+}
+
 KWindowSystemPrivate *KWaylandPlugin::createWindowSystem()
 {
     return new WindowSystem();
 }
+
+KWindowInfoPrivate *KWaylandPlugin::createWindowInfo(WId window, NET::Properties properties, NET::Properties2 properties2)
+{
+    return new WindowInfo(window, properties, properties2);
+}
